from setuptools import setup

setup(name='sm_ex1_probability',
      version='0.1',
      description='Gaussian and Binomial distributions',
      packages=['sm_ex1_probability'],
      zip_safe=False)
